#
# spec file for package aubio
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           aubio
%define libpkgname libaubio4
Summary:        Library for real-time audio labelling
License:        GPL-2.0-only
Group:          System/Libraries
BuildRequires:  alsa-devel
BuildRequires:  fftw3-devel
BuildRequires:  libjack-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  pkg-config
BuildRequires:  python
Version:        0.4.1
Release:        9.13.1
Source:         http://aubio.org/pub/%{name}-%{version}.tar.bz2
Source1:        http://aubio.org/pub/%{name}-%{version}.tar.bz2.asc
Source99:       baselibs.conf
# PATCH-FIX-UPSTREAM CVE-2017-17054 bsc#1070399
Patch1:         aubio-wavread-input-validation.patch
# PATCH-FIX-UPSTREAM CVE-2017-17554 bsc#1072317
Patch2:         aubio-resampler-NULL-deref-fix.patch
# PATCH-FIX-UPSTREAM CVE-2018-14523 bsc#1102364
Patch3:         0001-src-pitch-pitchyinfft.c-fix-out-of-bound-read-when-s.patch
Patch4:         0002-src-pitch-pitchyinfft.c-comment-out-debug-output.patch
# PATCH-FIX-UPSTREAM CVE-2018-14522 bsc#1102359
Patch6:         0002-src-io-source_wavread.c-also-exit-if-samplerate-is-n.patch
# PATCH-FIX-UPSTREAM CVE-2018-19800 bsc#1137828
Patch7:         CVE-2018-19800-tempo-fix-buffer-overflow-in-method-parser.patch
# PATCH-FIX-UPSTREAM CVE-2018-19801 bsc#1137822
Patch8:         CVE-2018-19801-filterbank-validate-input-parameters.patch
Url:            http://aubio.org
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%define debug_package_requires %{libpkgname} = %{version}-%{release}

%description
Aubio is a library for real time audio labelling. Its features include
segmenting a sound file before each of its attacks, performing pitch
detection, tapping the beat and producing midi streams from live audio.
The name aubio comes from 'audio' with a typo: several transcription
errors are likely to be found in the results too.

%package -n %{libpkgname}
Summary:        Library for real-time audio labelling
License:        GPL-2.0-only
Group:          System/Libraries

%description -n %{libpkgname}
Aubio is a library for real time audio labelling. Its features include
segmenting a sound file before each of its attacks, performing pitch
detection, tapping the beat and producing midi streams from live audio.
The name aubio comes from 'audio' with a typo: several transcription
errors are likely to be found in the results too.

%package -n libaubio-devel
Summary:        Development package for aubio library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
Requires:       %{libpkgname} = %{version}
Requires:       glibc-devel

%description -n libaubio-devel
This package contains the files needed to compile programs that use
aubio library.

%package tools
Summary:        Example programs for aubio library
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/Sound/Editors and Convertors

%description tools
This package includes the example programs for aubio library.

%prep
%setup -q
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
sed -e "s,/lib,/%_lib," src/wscript_build > src/wscript_build.new
diff -u src/wscript_build src/wscript_build.new || :
mv src/wscript_build.new src/wscript_build

%build
./waf configure --prefix=%{_prefix} --libdir=%{_libdir}
./waf build

%install
./waf install --destdir=%{buildroot}
rm %{buildroot}/%{_libdir}/libaubio.a

%post -n %{libpkgname} -p /sbin/ldconfig

%postun -n %{libpkgname} -p /sbin/ldconfig

%files -n %{libpkgname}
%defattr(-, root, root)
%{_libdir}/lib*.so.*

%files -n libaubio-devel
%defattr(-, root, root)
%doc AUTHORS ChangeLog COPYING README.md
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/*.pc
%{_includedir}/aubio

%files tools
%defattr(-, root, root)
%{_bindir}/*

%changelog
* Wed Jun 12 2019 tiwai@suse.de
- Fix two security issues leading to buffer overflow or segfault
  (CVE-2018-19800, bsc#1137828, CVE-2018-19801, bsc#1137822):
  CVE-2018-19800-tempo-fix-buffer-overflow-in-method-parser.patch
  CVE-2018-19801-filterbank-validate-input-parameters.patch
* Tue Aug  7 2018 tiwai@suse.de
- Fix minor security issues leading to segfault or buffer overread
  (CVE-2018-14522, bsc#1102359, CVE-2018-14523, bsc#1102364):
  0001-src-pitch-pitchyinfft.c-fix-out-of-bound-read-when-s.patch
  0002-src-pitch-pitchyinfft.c-comment-out-debug-output.patch
  0002-src-io-source_wavread.c-also-exit-if-samplerate-is-n.patch
- Refresh the previous fixes from the upstream version
  aubio-wavread-input-validation.patch
  aubio-resampler-NULL-deref-fix.patch
* Fri Jun  8 2018 tiwai@suse.de
- Fix segfault with malformed input file (CVE-2017-17554,
  bsc#1072317):
  aubio-resampler-NULL-deref-fix.patch
* Fri Mar 23 2018 tiwai@suse.de
- Fix divide-by-zero at wavread (CVE-2017-17054, bsc#1070399):
  aubio-wavread-input-validation.patch
* Sun Aug  3 2014 coolo@suse.com
- update to 0.4.1 (to fix build in Factory):
  * The most interesting feature in this release concerns aubiocut.
  Thanks to the sponsoring of Mark Suppes, the python script to slice
  sound streams was extended to be sample accurate, cut overlapping
  segments, and work on multiple channels.
  * New source and sink objects have been added to let aubio read and
  write WAV files, even when built with no external libraries.
  This should simplify the use of aubio on platforms such as Android or Windows.
  * Existing sources and sinks have been extended to read and write from
  and to multiple channels. This makes python-aubio one of the fastest
  and most versatile Python module to read and write media files.
  This release also comes with a stack of bug fixes and code clean-ups.
- 0.4 is a huge step in this library, as:
  * more portable: with no required dependencies, the core of aubio library,
  written in ANSI C, is known to compile and run on most modern platforms
  (Linux, Windows, Mac OS X, Android, iOS, ...).
  * more stable: several bugs fixes and a battery of tests make this new
  release more robust and less prone to errors.
  * faster: several enhancements to the C library and a brand new Python
  interface help make this release orders of magnitude faster than the
  previous ones.
- switched from autotools to waf
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sun Apr 24 2011 toddrme2178@gmail.com
- Add 32bit compatibility libraries
* Wed Oct 22 2008 mrueckert@suse.de
- fix debug_packages_requires define
* Fri Aug  1 2008 ro@suse.de
- fix requires for debuginfo package
* Wed Jul 16 2008 tiwai@suse.de
- initial version: 0.3.2
